// API endpoints
var configEndpoint = "/api/v4/config";
var filesEndpoint = "/api/v4/metadata";

// Tyoe to material icon map
var typeIconMap = {
  "directory": "folder",
  "file": "description",
  "audio": "headset",
  "image": "panorama",
  "app": "android",
  "video": "theaters",
  "document": "insert_chart",
  "contact": "person"
};

var languages = ["ar", "en"];

$(document).ready(function() {
  $.material.init();
  Vue.use(VueI18n);

  var vue = new Vue({
    el: 'html',
    data: { app: {files:[], secretKey: ""} },
    ready: function () {
      var $that = this;

      // App config initialization
      $.getJSON(configEndpoint).success(function(data, status) {
        data.files = [];
        data.secretKey = "";
        $that.app = data;
      });
    },
    methods:{
      loadFiles: function(){
        var $that = this;

        $.getJSON({url: filesEndpoint, headers: {'X-Secret-Key': this.app.secretKey}}).success(function(data, status) {
          var files = data.items;
          $.each(files, function(key, row){
            row.icon = typeIconMap[row.type.toLowerCase()];
            row.size = humanFileSize(row.size, true);
            row.url = row.url + '?secret_key=' + $that.app.secretKey;
          });

          $that.app.files = files;
          $that.app.zipFileUrl += '?secret_key=' + $that.app.secretKey;
        }).error(function(e) {
          $(".panel").not(':animated').effect("shake", {distance: 5}, 400);
        });
      },
      download: function (file, event) {
        event.preventDefault();
        event.stopPropagation();

        $el = $(this.el);
        $el.blur();

        // Mark as downloaded
        file.icon = "done";
        file.type = "done";
        file.thumb = null;

        var url = file.url;
        window.location.href = url;
      }
    }
  });

  vue.loadFiles();

  // i18n setup
  var lang = window.navigator.userLanguage || window.navigator.language || 'en';
  lang = lang.substring(0, 2);

  if($.inArray(lang, languages) < 0) {
    lang = 'en';
  }

  Vue.locale(lang, function () {
    return fetch('/lang/lang-' + lang + '.json', {
      method: 'get',
      headers: {
        'Accept': 'application/json',
        'Content-Type': 'application/json'
      }
    }).then(function (res) {
      return res.json();
    }).then(function (json) {
      if (Object.keys(json).length === 0) {
        return Promise.reject(new Error('locale empty !!'));
      } else {
        return Promise.resolve(json)
      }
    }).catch(function (error) {
      return Promise.reject();
    })
  }, function () {
    // We have to clear the language to trigger changes
    Vue.config.lang = '';
    Vue.config.lang = lang;
  });

});

function humanFileSize(bytes, si) {
  var thresh = si ? 1000 : 1024;
  if(Math.abs(bytes) < thresh) {
    return bytes + ' B';
  }
  var units = si ? ['kB','MB','GB','TB','PB','EB','ZB','YB'] : ['KiB','MiB','GiB','TiB','PiB','EiB','ZiB','YiB'];
  var u = -1;
  do {
    bytes /= thresh;
    ++u;
  } while(Math.abs(bytes) >= thresh && u < units.length - 1);
  return bytes.toFixed(2)+' '+units[u];
}
